pub unsafe extern "C" fn LLVMAddFunction(
M: LLVMModuleRef,
Name: *const c_char,
FunctionTy: LLVMTypeRef,
) -> LLVMValueRefExpand description
Add a function to a module under a specified name.
@see llvm::Function::Create()
pub unsafe extern "C" fn LLVMAddFunction(
M: LLVMModuleRef,
Name: *const c_char,
FunctionTy: LLVMTypeRef,
) -> LLVMValueRefAdd a function to a module under a specified name.
@see llvm::Function::Create()