pub unsafe extern "C" fn LLVMAddIncoming(
PhiNode: LLVMValueRef,
IncomingValues: *mut LLVMValueRef,
IncomingBlocks: *mut LLVMBasicBlockRef,
Count: c_uint,
)Expand description
Add an incoming value to the end of a PHI list.
pub unsafe extern "C" fn LLVMAddIncoming(
PhiNode: LLVMValueRef,
IncomingValues: *mut LLVMValueRef,
IncomingBlocks: *mut LLVMBasicBlockRef,
Count: c_uint,
)Add an incoming value to the end of a PHI list.