pub unsafe extern "C" fn LLVMAppendBasicBlock(
Fn: LLVMValueRef,
Name: *const c_char,
) -> LLVMBasicBlockRefExpand description
Append a basic block to the end of a function using the global context.
@see llvm::BasicBlock::Create()
pub unsafe extern "C" fn LLVMAppendBasicBlock(
Fn: LLVMValueRef,
Name: *const c_char,
) -> LLVMBasicBlockRefAppend a basic block to the end of a function using the global context.
@see llvm::BasicBlock::Create()