pub unsafe extern "C" fn LLVMAppendBasicBlockInContext(
C: LLVMContextRef,
Fn: LLVMValueRef,
Name: *const c_char,
) -> LLVMBasicBlockRefExpand description
Append a basic block to the end of a function.
@see llvm::BasicBlock::Create()
pub unsafe extern "C" fn LLVMAppendBasicBlockInContext(
C: LLVMContextRef,
Fn: LLVMValueRef,
Name: *const c_char,
) -> LLVMBasicBlockRefAppend a basic block to the end of a function.
@see llvm::BasicBlock::Create()