LLVMArrayType

Function LLVMArrayType 

pub unsafe extern "C" fn LLVMArrayType(
    ElementType: LLVMTypeRef,
    ElementCount: c_uint,
) -> LLVMTypeRef
Create a fixed size array type that refers to a specific type.

The created type will exist in the context that its element type exists in.

@deprecated LLVMArrayType is deprecated in favor of the API accurate LLVMArrayType2 @see llvm::ArrayType::get()