pub unsafe extern "C" fn LLVMConstIntGetSExtValue(
ConstantVal: LLVMValueRef,
) -> c_longlongExpand description
Obtain the sign extended value for an integer constant value.
@see llvm::ConstantInt::getSExtValue()
pub unsafe extern "C" fn LLVMConstIntGetSExtValue(
ConstantVal: LLVMValueRef,
) -> c_longlongObtain the sign extended value for an integer constant value.
@see llvm::ConstantInt::getSExtValue()