pub unsafe extern "C" fn LLVMConstIntGetZExtValue(
ConstantVal: LLVMValueRef,
) -> c_ulonglongExpand description
Obtain the zero extended value for an integer constant value.
@see llvm::ConstantInt::getZExtValue()
pub unsafe extern "C" fn LLVMConstIntGetZExtValue(
ConstantVal: LLVMValueRef,
) -> c_ulonglongObtain the zero extended value for an integer constant value.
@see llvm::ConstantInt::getZExtValue()