LLVMConstIntOfString

Function LLVMConstIntOfString 

pub unsafe extern "C" fn LLVMConstIntOfString(
    IntTy: LLVMTypeRef,
    Text: *const c_char,
    Radix: u8,
) -> LLVMValueRef
Obtain a constant value for an integer parsed from a string.

A similar API, LLVMConstIntOfStringAndSize is also available. If the string’s length is available, it is preferred to call that function instead.

@see llvm::ConstantInt::get()