pub unsafe extern "C" fn LLVMConstNull(
Ty: LLVMTypeRef,
) -> LLVMValueRefExpand description
Obtain a constant value referring to the null instance of a type.
@see llvm::Constant::getNullValue()
pub unsafe extern "C" fn LLVMConstNull(
Ty: LLVMTypeRef,
) -> LLVMValueRefObtain a constant value referring to the null instance of a type.
@see llvm::Constant::getNullValue()