pub unsafe extern "C" fn LLVMConstPointerNull(
Ty: LLVMTypeRef,
) -> LLVMValueRefExpand description
Obtain a constant that is a constant pointer pointing to NULL for a specified type.
pub unsafe extern "C" fn LLVMConstPointerNull(
Ty: LLVMTypeRef,
) -> LLVMValueRefObtain a constant that is a constant pointer pointing to NULL for a specified type.