pub unsafe extern "C" fn LLVMConstRealOfStringAndSize(
RealTy: LLVMTypeRef,
Text: *const c_char,
SLen: c_uint,
) -> LLVMValueRefExpand description
Obtain a constant for a floating point value parsed from a string.
pub unsafe extern "C" fn LLVMConstRealOfStringAndSize(
RealTy: LLVMTypeRef,
Text: *const c_char,
SLen: c_uint,
) -> LLVMValueRefObtain a constant for a floating point value parsed from a string.