pub unsafe extern "C" fn LLVMContextCreate() -> LLVMContextRefExpand description
Create a new context.
Every call to this function should be paired with a call to LLVMContextDispose() or the context will leak memory.
pub unsafe extern "C" fn LLVMContextCreate() -> LLVMContextRefCreate a new context.
Every call to this function should be paired with a call to LLVMContextDispose() or the context will leak memory.