pub unsafe extern "C" fn LLVMContextDispose(C: LLVMContextRef)Expand description
Destroy a context instance.
This should be called for every call to LLVMContextCreate() or memory will be leaked.
pub unsafe extern "C" fn LLVMContextDispose(C: LLVMContextRef)Destroy a context instance.
This should be called for every call to LLVMContextCreate() or memory will be leaked.