pub unsafe extern "C" fn LLVMContextSetDiscardValueNames(
C: LLVMContextRef,
Discard: LLVMBool,
)Expand description
Set whether the given context discards all value names.
If true, only the names of GlobalValue objects will be available in the IR. This can be used to save memory and runtime, especially in release mode.
@see LLVMContext::setDiscardValueNames()