pub unsafe extern "C" fn LLVMContextShouldDiscardValueNames(
C: LLVMContextRef,
) -> LLVMBoolExpand description
Retrieve whether the given context is set to discard all value names.
@see LLVMContext::shouldDiscardValueNames()
pub unsafe extern "C" fn LLVMContextShouldDiscardValueNames(
C: LLVMContextRef,
) -> LLVMBoolRetrieve whether the given context is set to discard all value names.
@see LLVMContext::shouldDiscardValueNames()