pub unsafe extern "C" fn LLVMCopyModuleFlagsMetadata(
M: LLVMModuleRef,
Len: *mut usize,
) -> *mut LLVMModuleFlagEntryExpand description
Returns the module flags as an array of flag-key-value triples. The caller is responsible for freeing this array by calling \c LLVMDisposeModuleFlagsMetadata.
@see Module::getModuleFlagsMetadata()