pub unsafe extern "C" fn LLVMCountIncoming(
PhiNode: LLVMValueRef,
) -> c_uintExpand description
Obtain the number of incoming basic blocks to a PHI node.
pub unsafe extern "C" fn LLVMCountIncoming(
PhiNode: LLVMValueRef,
) -> c_uintObtain the number of incoming basic blocks to a PHI node.