pub unsafe extern "C" fn LLVMCountStructElementTypes(
StructTy: LLVMTypeRef,
) -> c_uintExpand description
Get the number of elements defined inside the structure.
@see llvm::StructType::getNumElements()
pub unsafe extern "C" fn LLVMCountStructElementTypes(
StructTy: LLVMTypeRef,
) -> c_uintGet the number of elements defined inside the structure.
@see llvm::StructType::getNumElements()