LLVMCreateFunctionPassManagerForModule

Function LLVMCreateFunctionPassManagerForModule 

pub unsafe extern "C" fn LLVMCreateFunctionPassManagerForModule(
    M: LLVMModuleRef,
) -> LLVMPassManagerRef
Constructs a new function-by-function pass pipeline over the module provider. It does not take ownership of the module provider. This type of pipeline is suitable for code generation and JIT compilation tasks. @see llvm::FunctionPassManager::FunctionPassManager