pub unsafe extern "C" fn LLVMDbgRecordGetDebugLoc(
Rec: LLVMDbgRecordRef,
) -> LLVMMetadataRefExpand description
Get the debug location attached to the debug record.
@see llvm::DbgRecord::getDebugLoc()
pub unsafe extern "C" fn LLVMDbgRecordGetDebugLoc(
Rec: LLVMDbgRecordRef,
) -> LLVMMetadataRefGet the debug location attached to the debug record.
@see llvm::DbgRecord::getDebugLoc()