pub unsafe extern "C" fn LLVMDeleteFunction(Fn: LLVMValueRef)Expand description
Remove a function from its containing module and deletes it.
@see llvm::Function::eraseFromParent()
pub unsafe extern "C" fn LLVMDeleteFunction(Fn: LLVMValueRef)Remove a function from its containing module and deletes it.
@see llvm::Function::eraseFromParent()