pub unsafe extern "C" fn LLVMDisposePassManager(
PM: LLVMPassManagerRef,
)Expand description
Frees the memory of a pass pipeline. For function pipelines, does not free the module provider. @see llvm::PassManagerBase::~PassManagerBase.
pub unsafe extern "C" fn LLVMDisposePassManager(
PM: LLVMPassManagerRef,
)Frees the memory of a pass pipeline. For function pipelines, does not free the module provider. @see llvm::PassManagerBase::~PassManagerBase.