pub unsafe extern "C" fn LLVMEraseGlobalIFunc(IFunc: LLVMValueRef)Expand description
Remove a global indirect function from its parent module and delete it.
@see llvm::GlobalIFunc::eraseFromParent()
pub unsafe extern "C" fn LLVMEraseGlobalIFunc(IFunc: LLVMValueRef)Remove a global indirect function from its parent module and delete it.
@see llvm::GlobalIFunc::eraseFromParent()