pub unsafe extern "C" fn LLVMGetAllocatedType(
Alloca: LLVMValueRef,
) -> LLVMTypeRefExpand description
Obtain the type that is being allocated by the alloca instruction.
pub unsafe extern "C" fn LLVMGetAllocatedType(
Alloca: LLVMValueRef,
) -> LLVMTypeRefObtain the type that is being allocated by the alloca instruction.