pub unsafe extern "C" fn LLVMGetBasicBlockParent(
BB: LLVMBasicBlockRef,
) -> LLVMValueRefExpand description
Obtain the function to which a basic block belongs.
@see llvm::BasicBlock::getParent()
pub unsafe extern "C" fn LLVMGetBasicBlockParent(
BB: LLVMBasicBlockRef,
) -> LLVMValueRefObtain the function to which a basic block belongs.
@see llvm::BasicBlock::getParent()