pub unsafe extern "C" fn LLVMGetDebugLocColumn(
Val: LLVMValueRef,
) -> c_uintExpand description
Return the column number of the debug location for this value, which must be an llvm::Instruction.
@see llvm::Instruction::getDebugLoc()
pub unsafe extern "C" fn LLVMGetDebugLocColumn(
Val: LLVMValueRef,
) -> c_uintReturn the column number of the debug location for this value, which must be an llvm::Instruction.
@see llvm::Instruction::getDebugLoc()