pub unsafe extern "C" fn LLVMGetElementAsConstant(
C: LLVMValueRef,
idx: c_uint,
) -> LLVMValueRefExpand description
Get an element at specified index as a constant.
@see ConstantDataSequential::getElementAsConstant()
pub unsafe extern "C" fn LLVMGetElementAsConstant(
C: LLVMValueRef,
idx: c_uint,
) -> LLVMValueRefGet an element at specified index as a constant.
@see ConstantDataSequential::getElementAsConstant()