pub unsafe extern "C" fn LLVMGetElementType(
Ty: LLVMTypeRef,
) -> LLVMTypeRefExpand description
Obtain the element type of an array or vector type.
@see llvm::SequentialType::getElementType()
pub unsafe extern "C" fn LLVMGetElementType(
Ty: LLVMTypeRef,
) -> LLVMTypeRefObtain the element type of an array or vector type.
@see llvm::SequentialType::getElementType()