pub unsafe extern "C" fn LLVMGetEntryBasicBlock(
Fn: LLVMValueRef,
) -> LLVMBasicBlockRefExpand description
Obtain the basic block that corresponds to the entry point of a function.
@see llvm::Function::getEntryBlock()
pub unsafe extern "C" fn LLVMGetEntryBasicBlock(
Fn: LLVMValueRef,
) -> LLVMBasicBlockRefObtain the basic block that corresponds to the entry point of a function.
@see llvm::Function::getEntryBlock()