pub unsafe extern "C" fn LLVMGetEnumAttributeKind(
A: LLVMAttributeRef,
) -> c_uintExpand description
Get the unique id corresponding to the enum attribute passed as argument.
pub unsafe extern "C" fn LLVMGetEnumAttributeKind(
A: LLVMAttributeRef,
) -> c_uintGet the unique id corresponding to the enum attribute passed as argument.