pub unsafe extern "C" fn LLVMGetFirstFunction(
M: LLVMModuleRef,
) -> LLVMValueRefExpand description
Obtain an iterator to the first Function in a Module.
@see llvm::Module::begin()
pub unsafe extern "C" fn LLVMGetFirstFunction(
M: LLVMModuleRef,
) -> LLVMValueRefObtain an iterator to the first Function in a Module.
@see llvm::Module::begin()