LLVMGetFirstUse

Function LLVMGetFirstUse 

pub unsafe extern "C" fn LLVMGetFirstUse(
    Val: LLVMValueRef,
) -> LLVMUseRef
Obtain the first use of a value.

Uses are obtained in an iterator fashion. First, call this function to obtain a reference to the first use. Then, call LLVMGetNextUse() on that instance and all subsequently obtained instances until LLVMGetNextUse() returns NULL.

@see llvm::Value::use_begin()