pub unsafe extern "C" fn LLVMGetGC(Fn: LLVMValueRef) -> *const c_charExpand description
Obtain the name of the garbage collector to use during code generation.
@see llvm::Function::getGC()
pub unsafe extern "C" fn LLVMGetGC(Fn: LLVMValueRef) -> *const c_charObtain the name of the garbage collector to use during code generation.
@see llvm::Function::getGC()