LLVMGetGlobalParent

Function LLVMGetGlobalParent 

pub unsafe extern "C" fn LLVMGetGlobalParent(
    Global: LLVMValueRef,
) -> LLVMModuleRef
@defgroup LLVMCCoreValueConstantGlobals Global Values

This group contains functions that operate on global values. Functions in this group relate to functions in the llvm::GlobalValue class tree.

@see llvm::GlobalValue

@{