LLVMGetHandlers

Function LLVMGetHandlers 

pub unsafe extern "C" fn LLVMGetHandlers(
    CatchSwitch: LLVMValueRef,
    Handlers: *mut LLVMBasicBlockRef,
)
Obtain the basic blocks acting as handlers for a catchswitch instruction.

The Handlers parameter should point to a pre-allocated array of LLVMBasicBlockRefs at least LLVMGetNumHandlers() large. On return, the first LLVMGetNumHandlers() entries in the array will be populated with LLVMBasicBlockRef instances.

@param CatchSwitch The catchswitch instruction to operate on. @param Handlers Memory address of an array to be filled with basic blocks.