pub unsafe extern "C" fn LLVMGetICmpSameSign(
Inst: LLVMValueRef,
) -> LLVMBoolExpand description
Get whether or not an icmp instruction has the samesign flag.
This is only valid for instructions that correspond to llvm::ICmpInst.
@see llvm::ICmpInst::hasSameSign()