pub unsafe extern "C" fn LLVMGetInstructionParent(
Inst: LLVMValueRef,
) -> LLVMBasicBlockRefExpand description
Obtain the basic block to which an instruction belongs.
@see llvm::Instruction::getParent()
pub unsafe extern "C" fn LLVMGetInstructionParent(
Inst: LLVMValueRef,
) -> LLVMBasicBlockRefObtain the basic block to which an instruction belongs.
@see llvm::Instruction::getParent()