pub unsafe extern "C" fn LLVMGetIsDisjoint(
Inst: LLVMValueRef,
) -> LLVMBoolExpand description
Gets whether the instruction has the disjoint flag set. Only valid for or instructions.
pub unsafe extern "C" fn LLVMGetIsDisjoint(
Inst: LLVMValueRef,
) -> LLVMBoolGets whether the instruction has the disjoint flag set. Only valid for or instructions.