pub unsafe extern "C" fn LLVMGetLastFunction(
M: LLVMModuleRef,
) -> LLVMValueRefExpand description
Obtain an iterator to the last Function in a Module.
@see llvm::Module::end()
pub unsafe extern "C" fn LLVMGetLastFunction(
M: LLVMModuleRef,
) -> LLVMValueRefObtain an iterator to the last Function in a Module.
@see llvm::Module::end()