LLVMGetMaskValue

Function LLVMGetMaskValue 

pub unsafe extern "C" fn LLVMGetMaskValue(
    ShuffleVectorInst: LLVMValueRef,
    Elt: c_uint,
) -> c_int
Get the mask value at position Elt in the mask of a ShuffleVector instruction.

\Returns the result of \c LLVMGetUndefMaskElem() if the mask value is poison at that position.