pub unsafe extern "C" fn LLVMGetModuleContext(
M: LLVMModuleRef,
) -> LLVMContextRefExpand description
Obtain the context to which this module is associated.
@see Module::getContext()
pub unsafe extern "C" fn LLVMGetModuleContext(
M: LLVMModuleRef,
) -> LLVMContextRefObtain the context to which this module is associated.
@see Module::getContext()