pub unsafe extern "C" fn LLVMGetNamedMetadataNumOperands(
M: LLVMModuleRef,
Name: *const c_char,
) -> c_uintExpand description
Obtain the number of operands for named metadata in a module.
@see llvm::Module::getNamedMetadata()
pub unsafe extern "C" fn LLVMGetNamedMetadataNumOperands(
M: LLVMModuleRef,
Name: *const c_char,
) -> c_uintObtain the number of operands for named metadata in a module.
@see llvm::Module::getNamedMetadata()