pub unsafe extern "C" fn LLVMGetNextFunction(
Fn: LLVMValueRef,
) -> LLVMValueRefExpand description
Advance a Function iterator to the next Function.
Returns NULL if the iterator was already at the end and there are no more functions.
pub unsafe extern "C" fn LLVMGetNextFunction(
Fn: LLVMValueRef,
) -> LLVMValueRefAdvance a Function iterator to the next Function.
Returns NULL if the iterator was already at the end and there are no more functions.