LLVMGetNextInstruction

Function LLVMGetNextInstruction 

pub unsafe extern "C" fn LLVMGetNextInstruction(
    Inst: LLVMValueRef,
) -> LLVMValueRef
Obtain the instruction that occurs after the one specified.

The next instruction will be from the same basic block.

If this is the last instruction in a basic block, NULL will be returned.