LLVMGetNextNamedMetadata

Function LLVMGetNextNamedMetadata 

pub unsafe extern "C" fn LLVMGetNextNamedMetadata(
    NamedMDNode: LLVMNamedMDNodeRef,
) -> LLVMNamedMDNodeRef
Advance a NamedMDNode iterator to the next NamedMDNode.

Returns NULL if the iterator was already at the end and there are no more named metadata nodes.