pub unsafe extern "C" fn LLVMGetNextUse(U: LLVMUseRef) -> LLVMUseRefExpand description
Obtain the next use of a value.
This effectively advances the iterator. It returns NULL if you are on the final use and no more are available.
pub unsafe extern "C" fn LLVMGetNextUse(U: LLVMUseRef) -> LLVMUseRefObtain the next use of a value.
This effectively advances the iterator. It returns NULL if you are on the final use and no more are available.