pub unsafe extern "C" fn LLVMGetNumMaskElements(
ShuffleVectorInst: LLVMValueRef,
) -> c_uintExpand description
Get the number of elements in the mask of a ShuffleVector instruction.
pub unsafe extern "C" fn LLVMGetNumMaskElements(
ShuffleVectorInst: LLVMValueRef,
) -> c_uintGet the number of elements in the mask of a ShuffleVector instruction.