LLVMGetNumOperandBundleArgs

Function LLVMGetNumOperandBundleArgs 

pub unsafe extern "C" fn LLVMGetNumOperandBundleArgs(
    Bundle: LLVMOperandBundleRef,
) -> c_uint
Obtain the number of operands for an operand bundle.

@param Bundle Operand bundle to obtain operand count of. @return The number of operands. @see OperandBundleDef::input_size()