pub unsafe extern "C" fn LLVMGetNumSuccessors(
Term: LLVMValueRef,
) -> c_uintExpand description
Return the number of successors that this terminator has.
@see llvm::Instruction::getNumSuccessors
pub unsafe extern "C" fn LLVMGetNumSuccessors(
Term: LLVMValueRef,
) -> c_uintReturn the number of successors that this terminator has.
@see llvm::Instruction::getNumSuccessors