pub unsafe extern "C" fn LLVMGetOperand(
Val: LLVMValueRef,
Index: c_uint,
) -> LLVMValueRefExpand description
Obtain an operand at a specific index in a llvm::User value.
@see llvm::User::getOperand()
pub unsafe extern "C" fn LLVMGetOperand(
Val: LLVMValueRef,
Index: c_uint,
) -> LLVMValueRefObtain an operand at a specific index in a llvm::User value.
@see llvm::User::getOperand()