pub unsafe extern "C" fn LLVMGetOperandUse(
Val: LLVMValueRef,
Index: c_uint,
) -> LLVMUseRefExpand description
Obtain the use of an operand at a specific index in a llvm::User value.
@see llvm::User::getOperandUse()
pub unsafe extern "C" fn LLVMGetOperandUse(
Val: LLVMValueRef,
Index: c_uint,
) -> LLVMUseRefObtain the use of an operand at a specific index in a llvm::User value.
@see llvm::User::getOperandUse()