LLVMGetParamTypes

Function LLVMGetParamTypes 

pub unsafe extern "C" fn LLVMGetParamTypes(
    FunctionTy: LLVMTypeRef,
    Dest: *mut LLVMTypeRef,
)
Obtain the types of a function’s parameters.

The Dest parameter should point to a pre-allocated array of LLVMTypeRef at least LLVMCountParamTypes() large. On return, the first LLVMCountParamTypes() entries in the array will be populated with LLVMTypeRef instances.

@param FunctionTy The function type to operate on. @param Dest Memory address of an array to be filled with result.