LLVMGetSourceFileName

Function LLVMGetSourceFileName 

pub unsafe extern "C" fn LLVMGetSourceFileName(
    M: LLVMModuleRef,
    Len: *mut usize,
) -> *const c_char
Obtain the module’s original source file name.

@param M Module to obtain the name of @param Len Out parameter which holds the length of the returned string @return The original source file name of M @see Module::getSourceFileName()