pub unsafe extern "C" fn LLVMGetTypeContext(
Ty: LLVMTypeRef,
) -> LLVMContextRefExpand description
Obtain the context to which this type instance is associated.
@see llvm::Type::getContext()
pub unsafe extern "C" fn LLVMGetTypeContext(
Ty: LLVMTypeRef,
) -> LLVMContextRefObtain the context to which this type instance is associated.
@see llvm::Type::getContext()