pub unsafe extern "C" fn LLVMGetValueContext(
Val: LLVMValueRef,
) -> LLVMContextRefExpand description
Obtain the context to which this value is associated.
@see llvm::Value::getContext()
pub unsafe extern "C" fn LLVMGetValueContext(
Val: LLVMValueRef,
) -> LLVMContextRefObtain the context to which this value is associated.
@see llvm::Value::getContext()