pub unsafe extern "C" fn LLVMGlobalEraseMetadata(
Global: LLVMValueRef,
Kind: c_uint,
)Expand description
Erases a metadata attachment of the given kind if it exists.
@see llvm::GlobalObject::eraseMetadata()
pub unsafe extern "C" fn LLVMGlobalEraseMetadata(
Global: LLVMValueRef,
Kind: c_uint,
)Erases a metadata attachment of the given kind if it exists.
@see llvm::GlobalObject::eraseMetadata()