LLVMHalfType

Function LLVMHalfType 

pub unsafe extern "C" fn LLVMHalfType() -> LLVMTypeRef
Obtain a floating point type from the global context.

These map to the functions in this group of the same name.