pub unsafe extern "C" fn LLVMInitializeFunctionPassManager(
FPM: LLVMPassManagerRef,
) -> LLVMBoolExpand description
Initializes all of the function passes scheduled in the function pass manager. Returns 1 if any of the passes modified the module, 0 otherwise. @see llvm::FunctionPassManager::doInitialization