pub unsafe extern "C" fn LLVMInsertBasicBlock(
InsertBeforeBB: LLVMBasicBlockRef,
Name: *const c_char,
) -> LLVMBasicBlockRefExpand description
Insert a basic block in a function using the global context.
@see llvm::BasicBlock::Create()
pub unsafe extern "C" fn LLVMInsertBasicBlock(
InsertBeforeBB: LLVMBasicBlockRef,
Name: *const c_char,
) -> LLVMBasicBlockRefInsert a basic block in a function using the global context.
@see llvm::BasicBlock::Create()