LLVMInsertBasicBlockInContext

Function LLVMInsertBasicBlockInContext 

pub unsafe extern "C" fn LLVMInsertBasicBlockInContext(
    C: LLVMContextRef,
    BB: LLVMBasicBlockRef,
    Name: *const c_char,
) -> LLVMBasicBlockRef
Insert a basic block in a function before another basic block.

The function to add to is determined by the function of the passed basic block.

@see llvm::BasicBlock::Create()