pub unsafe extern "C" fn LLVMInt1Type() -> LLVMTypeRefExpand description
Obtain an integer type from the global context with a specified bit width.
pub unsafe extern "C" fn LLVMInt1Type() -> LLVMTypeRefObtain an integer type from the global context with a specified bit width.