pub unsafe extern "C" fn LLVMInt1TypeInContext(
C: LLVMContextRef,
) -> LLVMTypeRefExpand description
Obtain an integer type from a context with specified bit width.
pub unsafe extern "C" fn LLVMInt1TypeInContext(
C: LLVMContextRef,
) -> LLVMTypeRefObtain an integer type from a context with specified bit width.