LLVMIsATerminatorInst

Function LLVMIsATerminatorInst 

pub unsafe extern "C" fn LLVMIsATerminatorInst(
    Inst: LLVMValueRef,
) -> LLVMValueRef
Determine whether an instruction is a terminator. This routine is named to be compatible with historical functions that did this by querying the underlying C++ type.

@see llvm::Instruction::isTerminator()