pub unsafe extern "C" fn LLVMIsConstantString(
c: LLVMValueRef,
) -> LLVMBoolExpand description
Returns true if the specified constant is an array of i8.
@see ConstantDataSequential::getAsString()
pub unsafe extern "C" fn LLVMIsConstantString(
c: LLVMValueRef,
) -> LLVMBoolReturns true if the specified constant is an array of i8.
@see ConstantDataSequential::getAsString()