LLVMIsNewDbgInfoFormat

Function LLVMIsNewDbgInfoFormat 

pub unsafe extern "C" fn LLVMIsNewDbgInfoFormat(
    M: LLVMModuleRef,
) -> LLVMBool
Soon to be deprecated. See https://llvm.org/docs/RemoveDIsDebugInfo.html#c-api-changes

Returns true if the module is in the new debug info mode which uses non-instruction debug records instead of debug intrinsics for variable location tracking.