pub unsafe extern "C" fn LLVMIsTailCall(
CallInst: LLVMValueRef,
) -> LLVMBoolExpand description
Obtain whether a call instruction is a tail call.
This only works on llvm::CallInst instructions.
@see llvm::CallInst::isTailCall()
pub unsafe extern "C" fn LLVMIsTailCall(
CallInst: LLVMValueRef,
) -> LLVMBoolObtain whether a call instruction is a tail call.
This only works on llvm::CallInst instructions.
@see llvm::CallInst::isTailCall()