LLVMPointerType

Function LLVMPointerType 

pub unsafe extern "C" fn LLVMPointerType(
    ElementType: LLVMTypeRef,
    AddressSpace: c_uint,
) -> LLVMTypeRef
Create a pointer type that points to a defined type.

The created type will exist in the context that its pointee type exists in.

@see llvm::PointerType::get()