pub unsafe extern "C" fn LLVMRemoveGlobalIFunc(IFunc: LLVMValueRef)Expand description
Remove a global indirect function from its parent module.
This unlinks the global indirect function from its containing module but keeps it alive.
@see llvm::GlobalIFunc::removeFromParent()