LLVMRunPassManager

Function LLVMRunPassManager 

pub unsafe extern "C" fn LLVMRunPassManager(
    PM: LLVMPassManagerRef,
    M: LLVMModuleRef,
) -> LLVMBool
Initializes, executes on the provided module, and finalizes all of the passes scheduled in the pass manager. Returns 1 if any of the passes modified the module, 0 otherwise. @see llvm::PassManager::run(Module&)