LLVMSearchForAddressOfSymbol

Function LLVMSearchForAddressOfSymbol 

pub unsafe extern "C" fn LLVMSearchForAddressOfSymbol(
    symbolName: *const c_char,
) -> *mut c_void
This function will search through all previously loaded dynamic libraries for the symbol \p symbolName. If it is found, the address of that symbol is returned. If not, null is returned.

@see sys::DynamicLibrary::SearchForAddressOfSymbol()