pub unsafe extern "C" fn LLVMSetGC(
Fn: LLVMValueRef,
Name: *const c_char,
)Expand description
Define the garbage collector to use during code generation.
@see llvm::Function::setGC()
pub unsafe extern "C" fn LLVMSetGC(
Fn: LLVMValueRef,
Name: *const c_char,
)Define the garbage collector to use during code generation.
@see llvm::Function::setGC()