pub unsafe extern "C" fn LLVMSetInstDebugLocation(
Builder: LLVMBuilderRef,
Inst: LLVMValueRef,
)Expand description
Attempts to set the debug location for the given instruction using the current debug location for the given builder. If the builder has no current debug location, this function is a no-op.
@deprecated LLVMSetInstDebugLocation is deprecated in favor of the more general LLVMAddMetadataToInst.
@see llvm::IRBuilder::SetInstDebugLocation()