pub unsafe extern "C" fn LLVMSetOperand(
User: LLVMValueRef,
Index: c_uint,
Val: LLVMValueRef,
)Expand description
Set an operand at a specific index in a llvm::User value.
@see llvm::User::setOperand()
pub unsafe extern "C" fn LLVMSetOperand(
User: LLVMValueRef,
Index: c_uint,
Val: LLVMValueRef,
)Set an operand at a specific index in a llvm::User value.
@see llvm::User::setOperand()