LLVMSetSourceFileName

Function LLVMSetSourceFileName 

pub unsafe extern "C" fn LLVMSetSourceFileName(
    M: LLVMModuleRef,
    Name: *const c_char,
    Len: usize,
)
Set the original source file name of a module to a string Name with length Len.

@param M The module to set the source file name of @param Name The string to set M’s source file name to @param Len Length of Name @see Module::setSourceFileName()