pub unsafe extern "C" fn LLVMSetSuccessor(
Term: LLVMValueRef,
i: c_uint,
block: LLVMBasicBlockRef,
)Expand description
Update the specified successor to point at the provided block.
@see llvm::Instruction::setSuccessor
pub unsafe extern "C" fn LLVMSetSuccessor(
Term: LLVMValueRef,
i: c_uint,
block: LLVMBasicBlockRef,
)Update the specified successor to point at the provided block.
@see llvm::Instruction::setSuccessor