pub unsafe extern "C" fn LLVMSetTailCall(
CallInst: LLVMValueRef,
IsTailCall: LLVMBool,
)Expand description
Set whether a call instruction is a tail call.
This only works on llvm::CallInst instructions.
@see llvm::CallInst::setTailCall()
pub unsafe extern "C" fn LLVMSetTailCall(
CallInst: LLVMValueRef,
IsTailCall: LLVMBool,
)Set whether a call instruction is a tail call.
This only works on llvm::CallInst instructions.
@see llvm::CallInst::setTailCall()