pub unsafe extern "C" fn LLVMStructCreateNamed(
C: LLVMContextRef,
Name: *const c_char,
) -> LLVMTypeRefExpand description
Create an empty structure in a context having a specified name.
@see llvm::StructType::create()
pub unsafe extern "C" fn LLVMStructCreateNamed(
C: LLVMContextRef,
Name: *const c_char,
) -> LLVMTypeRefCreate an empty structure in a context having a specified name.
@see llvm::StructType::create()