pub unsafe extern "C" fn LLVMStructGetTypeAtIndex(
StructTy: LLVMTypeRef,
i: c_uint,
) -> LLVMTypeRefExpand description
Get the type of the element at a given index in the structure.
@see llvm::StructType::getTypeAtIndex()
pub unsafe extern "C" fn LLVMStructGetTypeAtIndex(
StructTy: LLVMTypeRef,
i: c_uint,
) -> LLVMTypeRefGet the type of the element at a given index in the structure.
@see llvm::StructType::getTypeAtIndex()