pub unsafe extern "C" fn LLVMStructType(
ElementTypes: *mut LLVMTypeRef,
ElementCount: c_uint,
Packed: LLVMBool,
) -> LLVMTypeRefExpand description
Create a new structure type in the global context.
@see llvm::StructType::create()
pub unsafe extern "C" fn LLVMStructType(
ElementTypes: *mut LLVMTypeRef,
ElementCount: c_uint,
Packed: LLVMBool,
) -> LLVMTypeRefCreate a new structure type in the global context.
@see llvm::StructType::create()