pub unsafe extern "C" fn LLVMTypeIsSized(Ty: LLVMTypeRef) -> LLVMBoolExpand description
Whether the type has a known size.
Things that don’t have a size are abstract types, labels, and void.a
@see llvm::Type::isSized()
pub unsafe extern "C" fn LLVMTypeIsSized(Ty: LLVMTypeRef) -> LLVMBoolWhether the type has a known size.
Things that don’t have a size are abstract types, labels, and void.a
@see llvm::Type::isSized()