pub unsafe extern "C" fn LLVMValueMetadataEntriesGetKind(
Entries: *mut LLVMValueMetadataEntry,
Index: c_uint,
) -> c_uintExpand description
Returns the kind of a value metadata entry at a specific index.
pub unsafe extern "C" fn LLVMValueMetadataEntriesGetKind(
Entries: *mut LLVMValueMetadataEntry,
Index: c_uint,
) -> c_uintReturns the kind of a value metadata entry at a specific index.