pub unsafe extern "C" fn LLVMVoidType() -> LLVMTypeRefExpand description
These are similar to the above functions except they operate on the global context.
pub unsafe extern "C" fn LLVMVoidType() -> LLVMTypeRefThese are similar to the above functions except they operate on the global context.