pub unsafe extern "C" fn mlirBlockArgumentSetLocation(
value: MlirValue,
loc: MlirLocation,
)Expand description
Sets the location of the block argument to the given location.
pub unsafe extern "C" fn mlirBlockArgumentSetLocation(
value: MlirValue,
loc: MlirLocation,
)Sets the location of the block argument to the given location.