pub unsafe extern "C" fn mlirComplexAttrGetRealDouble(
attr: MlirAttribute,
) -> f64Expand description
Returns the real value stored in the given complex attribute, interpreting the value as double.
pub unsafe extern "C" fn mlirComplexAttrGetRealDouble(
attr: MlirAttribute,
) -> f64Returns the real value stored in the given complex attribute, interpreting the value as double.