pub unsafe extern "C" fn mlirContextGetNumThreads(
context: MlirContext,
) -> c_uintExpand description
Gets the number of threads of the thread pool of the context when multithreading is enabled. Returns 1 if no multithreading.
pub unsafe extern "C" fn mlirContextGetNumThreads(
context: MlirContext,
) -> c_uintGets the number of threads of the thread pool of the context when multithreading is enabled. Returns 1 if no multithreading.