pub unsafe extern "C" fn mlirContextGetThreadPool(
context: MlirContext,
) -> MlirLlvmThreadPoolExpand description
Gets the thread pool of the context when enabled multithreading, otherwise an assertion is raised.
pub unsafe extern "C" fn mlirContextGetThreadPool(
context: MlirContext,
) -> MlirLlvmThreadPoolGets the thread pool of the context when enabled multithreading, otherwise an assertion is raised.