mlirExecutionEngineCreate

Function mlirExecutionEngineCreate 

pub unsafe extern "C" fn mlirExecutionEngineCreate(
    op: MlirModule,
    optLevel: c_int,
    numPaths: c_int,
    sharedLibPaths: *const MlirStringRef,
    enableObjectDump: bool,
    enablePIC: bool,
) -> MlirExecutionEngine
Creates an ExecutionEngine for the provided ModuleOp. The ModuleOp is expected to be “translatable” to LLVM IR (only contains operations in dialects that implement the LLVMTranslationDialectInterface). The module ownership stays with the client and can be destroyed as soon as the call returns. optLevel is the optimization level to be used for transformation and code generation. LLVM passes at optLevel are run before code generation. The number and array of paths corresponding to shared libraries that will be loaded are specified via numPaths and sharedLibPaths respectively. The enablePIC arguments controls the relocation model, when true the generated code is emitted as “position independent”, making it possible to save it and reload it as a shared object in another process. TODO: figure out other options.