pub unsafe extern "C" fn mlirFreezeRewritePattern(
set: MlirRewritePatternSet,
) -> MlirFrozenRewritePatternSetExpand description
Freeze the given MlirRewritePatternSet to a MlirFrozenRewritePatternSet. Note that the ownership of the input set is transferred into the frozen set after this call.