pub unsafe extern "C" fn mlirGreedyRewriteDriverConfigGetMaxIterations(
config: MlirGreedyRewriteDriverConfig,
) -> i64Expand description
Gets the maximum number of iterations for the greedy rewrite driver.
pub unsafe extern "C" fn mlirGreedyRewriteDriverConfigGetMaxIterations(
config: MlirGreedyRewriteDriverConfig,
) -> i64Gets the maximum number of iterations for the greedy rewrite driver.