pub unsafe extern "C" fn mlirGreedyRewriteDriverConfigGetMaxNumRewrites(
config: MlirGreedyRewriteDriverConfig,
) -> i64Expand description
Gets the maximum number of rewrites within an iteration.
pub unsafe extern "C" fn mlirGreedyRewriteDriverConfigGetMaxNumRewrites(
config: MlirGreedyRewriteDriverConfig,
) -> i64Gets the maximum number of rewrites within an iteration.