pub unsafe extern "C" fn mlirGreedyRewriteDriverConfigGetStrictness(
config: MlirGreedyRewriteDriverConfig,
) -> MlirGreedyRewriteStrictnessExpand description
Gets the strictness level for the greedy rewrite driver.
pub unsafe extern "C" fn mlirGreedyRewriteDriverConfigGetStrictness(
config: MlirGreedyRewriteDriverConfig,
) -> MlirGreedyRewriteStrictnessGets the strictness level for the greedy rewrite driver.