pub unsafe extern "C" fn mlirGreedyRewriteDriverConfigSetMaxNumRewrites(
config: MlirGreedyRewriteDriverConfig,
maxNumRewrites: i64,
)Expand description
Sets the maximum number of rewrites within an iteration. Use -1 for no limit.
pub unsafe extern "C" fn mlirGreedyRewriteDriverConfigSetMaxNumRewrites(
config: MlirGreedyRewriteDriverConfig,
maxNumRewrites: i64,
)Sets the maximum number of rewrites within an iteration. Use -1 for no limit.