pub unsafe extern "C" fn mlirGreedyRewriteDriverConfigSetStrictness(
config: MlirGreedyRewriteDriverConfig,
strictness: MlirGreedyRewriteStrictness,
)Expand description
Sets the strictness level for the greedy rewrite driver.
pub unsafe extern "C" fn mlirGreedyRewriteDriverConfigSetStrictness(
config: MlirGreedyRewriteDriverConfig,
strictness: MlirGreedyRewriteStrictness,
)Sets the strictness level for the greedy rewrite driver.