pub unsafe extern "C" fn mlirIntegerSetAttrGet(
set: MlirIntegerSet,
) -> MlirAttributeExpand description
Creates an integer set attribute wrapping the given set. The attribute belongs to the same context as the integer set.
pub unsafe extern "C" fn mlirIntegerSetAttrGet(
set: MlirIntegerSet,
) -> MlirAttributeCreates an integer set attribute wrapping the given set. The attribute belongs to the same context as the integer set.