pub unsafe extern "C" fn mlirModuleCreateParseFromFile(
context: MlirContext,
fileName: MlirStringRef,
) -> MlirModuleExpand description
Parses a module from file and transfers ownership to the caller.
pub unsafe extern "C" fn mlirModuleCreateParseFromFile(
context: MlirContext,
fileName: MlirStringRef,
) -> MlirModuleParses a module from file and transfers ownership to the caller.