mlirOperationIsBeforeInBlock

Function mlirOperationIsBeforeInBlock 

pub unsafe extern "C" fn mlirOperationIsBeforeInBlock(
    op: MlirOperation,
    other: MlirOperation,
) -> bool
Given an operation ‘other’ that is within the same parent block, return whether the current operation is before ‘other’ in the operation list of the parent block. Note: This function has an average complexity of O(1), but worst case may take O(N) where N is the number of operations within the parent block.