pub unsafe extern "C" fn mlirPDLValueAsAttribute(
value: MlirPDLValue,
) -> MlirAttributeExpand description
Cast the MlirPDLValue to an MlirAttribute. Return a null value if the cast fails, just like llvm::dyn_cast.
pub unsafe extern "C" fn mlirPDLValueAsAttribute(
value: MlirPDLValue,
) -> MlirAttributeCast the MlirPDLValue to an MlirAttribute. Return a null value if the cast fails, just like llvm::dyn_cast.