pub unsafe extern "C" fn mlirPDLValueAsOperation(
value: MlirPDLValue,
) -> MlirOperationExpand description
Cast the MlirPDLValue to an MlirOperation. Return a null value if the cast fails, just like llvm::dyn_cast.
pub unsafe extern "C" fn mlirPDLValueAsOperation(
value: MlirPDLValue,
) -> MlirOperationCast the MlirPDLValue to an MlirOperation. Return a null value if the cast fails, just like llvm::dyn_cast.