pub unsafe extern "C" fn mlirPDLValueAsType(
value: MlirPDLValue,
) -> MlirTypeExpand description
Cast the MlirPDLValue to an MlirType. Return a null value if the cast fails, just like llvm::dyn_cast.
pub unsafe extern "C" fn mlirPDLValueAsType(
value: MlirPDLValue,
) -> MlirTypeCast the MlirPDLValue to an MlirType. Return a null value if the cast fails, just like llvm::dyn_cast.