pub unsafe extern "C" fn mlirPDLValueAsValue(
value: MlirPDLValue,
) -> MlirValueExpand description
Cast the MlirPDLValue to an MlirValue. Return a null value if the cast fails, just like llvm::dyn_cast.
pub unsafe extern "C" fn mlirPDLValueAsValue(
value: MlirPDLValue,
) -> MlirValueCast the MlirPDLValue to an MlirValue. Return a null value if the cast fails, just like llvm::dyn_cast.