mlirRewriterBaseSetInsertionPointAfter

Function mlirRewriterBaseSetInsertionPointAfter 

pub unsafe extern "C" fn mlirRewriterBaseSetInsertionPointAfter(
    rewriter: MlirRewriterBase,
    op: MlirOperation,
)
Sets the insertion point to the node after the specified operation, which will cause subsequent insertions to go right after it.