pub unsafe extern "C" fn mlirSMTAttrCheckIntPredicate(
ctx: MlirContext,
str_: MlirStringRef,
) -> boolExpand description
Checks if the given string is a valid smt::IntPredicate.
pub unsafe extern "C" fn mlirSMTAttrCheckIntPredicate(
ctx: MlirContext,
str_: MlirStringRef,
) -> boolChecks if the given string is a valid smt::IntPredicate.