pub unsafe extern "C" fn mlirSMTTypeGetArray(
ctx: MlirContext,
domainType: MlirType,
rangeType: MlirType,
) -> MlirTypeExpand description
Creates an array type with the given domain and range types.
pub unsafe extern "C" fn mlirSMTTypeGetArray(
ctx: MlirContext,
domainType: MlirType,
rangeType: MlirType,
) -> MlirTypeCreates an array type with the given domain and range types.