mlirShapedTypeIsDynamicStrideOrOffset

Function mlirShapedTypeIsDynamicStrideOrOffset 

pub unsafe extern "C" fn mlirShapedTypeIsDynamicStrideOrOffset(
    val: i64,
) -> bool
Checks whether the given value is used as a placeholder for dynamic strides and offsets in shaped types.