mlirSimplifyAffineExpr

Function mlirSimplifyAffineExpr 

pub unsafe extern "C" fn mlirSimplifyAffineExpr(
    expr: MlirAffineExpr,
    numDims: u32,
    numSymbols: u32,
) -> MlirAffineExpr
Simplify an affine expression by flattening and some amount of simple analysis. This has complexity linear in the number of nodes in ‘expr’. Returns the simplified expression, which is the same as the input expression if it can’t be simplified. When expr is semi-affine, a simplified semi-affine expression is constructed in the sorted order of dimension and symbol positions.