pub unsafe extern "C" fn mlirValueGetContext(
v: MlirValue,
) -> MlirContextExpand description
Gets the context that a value was created with.
pub unsafe extern "C" fn mlirValueGetContext(
v: MlirValue,
) -> MlirContextGets the context that a value was created with.