pub unsafe extern "C" fn mlirWalkAndApplyPatterns(
op: MlirOperation,
patterns: MlirFrozenRewritePatternSet,
)Expand description
Applies the given patterns to the given op by a fast walk-based pattern rewrite driver.
pub unsafe extern "C" fn mlirWalkAndApplyPatterns(
op: MlirOperation,
patterns: MlirFrozenRewritePatternSet,
)Applies the given patterns to the given op by a fast walk-based pattern rewrite driver.