pub unsafe extern "C" fn LLVMConstRealGetDouble(
ConstantVal: LLVMValueRef,
losesInfo: *mut LLVMBool,
) -> f64Expand description
Obtain the double value for an floating point constant value. losesInfo indicates if some precision was lost in the conversion.
@see llvm::ConstantFP::getDoubleValue