pub unsafe extern "C" fn LLVMCreateBuilderInContext(
C: LLVMContextRef,
) -> LLVMBuilderRefExpand description
@defgroup LLVMCCoreInstructionBuilder Instruction Builders
An instruction builder represents a point within a basic block and is the exclusive means of building instructions using the C interface.
@{