pub unsafe extern "C" fn LLVMCreateOperandBundle(
Tag: *const c_char,
TagLen: usize,
Args: *mut LLVMValueRef,
NumArgs: c_uint,
) -> LLVMOperandBundleRefExpand description
Create a new operand bundle.
Every invocation should be paired with LLVMDisposeOperandBundle() or memory will be leaked.
@param Tag Tag name of the operand bundle @param TagLen Length of Tag @param Args Memory address of an array of bundle operands @param NumArgs Length of Args