pub unsafe extern "C" fn LLVMDeleteBasicBlock(BB: LLVMBasicBlockRef)Expand description
Remove a basic block from a function and delete it.
This deletes the basic block from its containing function and deletes the basic block itself.
@see llvm::BasicBlock::eraseFromParent()