pub unsafe extern "C" fn LLVMEnablePrettyStackTrace()Expand description
Enable LLVM’s built-in stack trace code. This intercepts the OS’s crash signals and prints which component of LLVM you were in at the time if the crash.
pub unsafe extern "C" fn LLVMEnablePrettyStackTrace()Enable LLVM’s built-in stack trace code. This intercepts the OS’s crash signals and prints which component of LLVM you were in at the time if the crash.