pub unsafe extern "C" fn LLVMFinalizeFunctionPassManager(
FPM: LLVMPassManagerRef,
) -> LLVMBoolExpand description
Finalizes all of the function passes scheduled in the function pass manager. Returns 1 if any of the passes modified the module, 0 otherwise. @see llvm::FunctionPassManager::doFinalization