pub unsafe extern "C" fn LLVMFunctionType(
ReturnType: LLVMTypeRef,
ParamTypes: *mut LLVMTypeRef,
ParamCount: c_uint,
IsVarArg: LLVMBool,
) -> LLVMTypeRefExpand description
Obtain a function type consisting of a specified signature.
The function is defined as a tuple of a return Type, a list of parameter types, and whether the function is variadic.