pub unsafe extern "C" fn LLVMGetDataLayoutStr(
M: LLVMModuleRef,
) -> *const c_charExpand description
Obtain the data layout for a module.
@see Module::getDataLayoutStr()
LLVMGetDataLayout is DEPRECATED, as the name is not only incorrect, but match the name of another method on the module. Prefer the use of LLVMGetDataLayoutStr, which is not ambiguous.