pub unsafe extern "C" fn LLVMGetOperandBundleArgAtIndex(
Bundle: LLVMOperandBundleRef,
Index: c_uint,
) -> LLVMValueRefExpand description
Obtain the operand for an operand bundle at the given index.
@param Bundle Operand bundle to obtain operand of. @param Index An operand index, must be less than LLVMGetNumOperandBundleArgs(). @return The operand.