pub unsafe extern "C" fn LLVMGetPreviousNamedMetadata(
NamedMDNode: LLVMNamedMDNodeRef,
) -> LLVMNamedMDNodeRefExpand description
Decrement a NamedMDNode iterator to the previous NamedMDNode.
Returns NULL if the iterator was already at the beginning and there are no previous named metadata nodes.