pub unsafe extern "C" fn LLVMGetStructElementTypes(
StructTy: LLVMTypeRef,
Dest: *mut LLVMTypeRef,
)Expand description
Get the elements within a structure.
The function is passed the address of a pre-allocated array of LLVMTypeRef at least LLVMCountStructElementTypes() long. After invocation, this array will be populated with the structure’s elements. The objects in the destination array will have a lifetime of the structure type itself, which is the lifetime of the context it is contained in.