pub unsafe extern "C" fn LLVMGetVersion(
Major: *mut c_uint,
Minor: *mut c_uint,
Patch: *mut c_uint,
)Expand description
Return the major, minor, and patch version of LLVM
The version components are returned via the function’s three output parameters or skipped if a NULL pointer was supplied.