pub unsafe extern "C" fn LLVMGlobalCopyAllMetadata(
Value: LLVMValueRef,
NumEntries: *mut usize,
) -> *mut LLVMValueMetadataEntryExpand description
Retrieves an array of metadata entries representing the metadata attached to this value. The caller is responsible for freeing this array by calling \c LLVMDisposeValueMetadataEntries.
@see llvm::GlobalObject::getAllMetadata()