pub unsafe extern "C" fn LLVMGlobalSetMetadata(
Global: LLVMValueRef,
Kind: c_uint,
MD: LLVMMetadataRef,
)Expand description
Sets a metadata attachment, erasing the existing metadata attachment if it already exists for the given kind.
@see llvm::GlobalObject::setMetadata()