pub unsafe extern "C" fn LLVMHalfType() -> LLVMTypeRefExpand description
Obtain a floating point type from the global context.
These map to the functions in this group of the same name.
pub unsafe extern "C" fn LLVMHalfType() -> LLVMTypeRefObtain a floating point type from the global context.
These map to the functions in this group of the same name.