pub unsafe extern "C" fn LLVMInstallFatalErrorHandler(
Handler: LLVMFatalErrorHandler,
)Expand description
Install a fatal error handler. By default, if LLVM detects a fatal error, it will call exit(1). This may not be appropriate in many contexts. For example, doing exit(1) will bypass many crash reporting/tracing system tools. This function allows you to install a callback that will be invoked prior to the call to exit(1).