pub unsafe extern "C" fn LLVMIntrinsicCopyOverloadedName2(
Mod: LLVMModuleRef,
ID: c_uint,
ParamTypes: *mut LLVMTypeRef,
ParamCount: usize,
NameLength: *mut usize,
) -> *mut c_charExpand description
Copies the name of an overloaded intrinsic identified by a given list of parameter types.
Unlike LLVMIntrinsicGetName, the caller is responsible for freeing the returned string.
This version also supports unnamed types.
@see llvm::Intrinsic::getName()