pub unsafe extern "C" fn LLVMMDStringInContext2(
C: LLVMContextRef,
Str: *const c_char,
SLen: usize,
) -> LLVMMetadataRefExpand description
Create an MDString value from a given string value.
The MDString value does not take ownership of the given string, it remains the responsibility of the caller to free it.
@see llvm::MDString::get()