pub unsafe extern "C" fn LLVMRunFunctionPassManager(
FPM: LLVMPassManagerRef,
F: LLVMValueRef,
) -> LLVMBoolExpand description
Executes all of the function passes scheduled in the function pass manager on the provided function. Returns 1 if any of the passes modified the function, false otherwise. @see llvm::FunctionPassManager::run(Function&)