pub unsafe extern "C" fn LLVMScalableVectorType(
ElementType: LLVMTypeRef,
ElementCount: c_uint,
) -> LLVMTypeRefExpand description
Create a vector type that contains a defined type and has a scalable number of elements.
The created type will exist in the context thats its element type exists in.
@see llvm::ScalableVectorType::get()