pub unsafe extern "C" fn mlirComplexAttrDoubleGet(
ctx: MlirContext,
type_: MlirType,
real: f64,
imag: f64,
) -> MlirAttributeExpand description
Creates a complex attribute in the given context with the given double real and imaginary values and double-precision FP semantics.